@@ -9,7 +9,6 @@ use super::driver;
 mod doc_props_app;
 mod doc_props_core;
 mod workbook;
-mod workbook_rels;
 mod worksheet;
 mod rels;
 mod theme;
@@ -19,11 +18,13 @@ mod vml_drawing;
 mod drawing;
 mod vba_project_bin;
 mod comment;
+mod workbook_rels;
 pub(crate) mod chart;
 pub(crate) mod drawing_rels;
 pub(crate) mod worksheet_rels;
 pub(crate) mod media;
 pub(crate) mod embeddings;
+pub(crate) mod vml_drawing_rels;
 
 #[derive(Debug)]
 pub enum XlsxError {
@@ -65,7 +66,7 @@ impl From<FromUtf8Error> for XlsxError {
 pub fn read_reader<R: io::Read+io::Seek>(reader: R)->Result<Spreadsheet, XlsxError> {
     let mut arv = zip::read::ZipArchive::new(reader)?;
 
-    let (mut book, sheets) = workbook::read(&mut arv).unwrap();
+    let (mut book, sheets, defined_names) = workbook::read(&mut arv).unwrap();
     doc_props_app::read(&mut arv, &mut book).unwrap();
     doc_props_core::read(&mut arv, &mut book).unwrap(); 
     vba_project_bin::read(&mut arv, &mut book).unwrap();
@@ -88,7 +89,7 @@ pub fn read_reader<R: io::Read+io::Seek>(reader: R)->Result<Spreadsheet, XlsxErr
     for (sheets_name, sheets_sheet_id, sheets_rid) in &sheets {
         for (rel_id, _, rel_target) in &workbook_rel {
             if sheets_rid == rel_id {
-                let (_drawing_id, _legacy_drawing_id, hyperlink_vec) = worksheet::read(&mut arv, &rel_target, &mut book, sheets_sheet_id, sheets_name).unwrap();
+                let (_drawing_id, legacy_drawing_id, hyperlink_vec) = worksheet::read(&mut arv, &rel_target, &mut book, sheets_sheet_id, sheets_name).unwrap();
                 let worksheet = book.get_sheet_by_sheet_id_mut(sheets_sheet_id).unwrap();
                 let worksheet_rel = worksheet_rels::read(&mut arv, &rel_target, &hyperlink_vec, worksheet).unwrap();
                 for (_worksheet_id, type_value, worksheet_target) in &worksheet_rel {
@@ -99,13 +100,30 @@ pub fn read_reader<R: io::Read+io::Seek>(reader: R)->Result<Spreadsheet, XlsxErr
                         },
                         // comment
                         "http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments" => {
-                            let vml_drawing_target = get_vml_drawing_target(&worksheet_rel);
-                            let mut vml_drawing_list = vml_drawing::read(&mut arv, vml_drawing_target).unwrap();
-                            let _ = comment::read(&mut arv, &worksheet_target, worksheet, &mut vml_drawing_list, &theme).unwrap();
+                            let _ = comment::read(&mut arv, &worksheet_target, worksheet, &theme).unwrap();
                         },
                         _ => {}
                     }
                 }
+                for (worksheet_id, _type_value, worksheet_target) in &worksheet_rel {
+                    match &legacy_drawing_id {
+                        Some(v) => {
+                            if v == worksheet_id {
+                                let _ = vml_drawing::read(&mut arv, worksheet_target, worksheet).unwrap();
+                            }
+                        },
+                        None => {}
+                    }
+                }
+            }
+        }
+    }
+
+    for sheet in book.get_sheet_collection_mut() {
+        for defined_name in &defined_names {
+            let def_sheet_name = defined_name.get_address_obj().get_sheet_name();
+            if sheet.get_title() == def_sheet_name {
+                sheet.add_defined_names(defined_name.clone());
             }
         }
     }
