@@ -1,35 +1,37 @@
 // b
 use super::BooleanValue;
-use writer::driver::*;
-use reader::driver::*;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Bold {
     pub(crate) val: BooleanValue,
 }
 impl Bold {
-    pub fn get_val(&self)-> &bool {
+    pub fn get_val(&self) -> &bool {
         &self.val.get_value()
     }
 
-    pub fn set_val(&mut self, value:bool)-> &mut Self {
+    pub fn set_val(&mut self, value: bool) -> &mut Self {
         self.val.set_value(value);
         self
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<std::io::BufReader<std::fs::File>>,
-        e:&BytesStart
+        _reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         self.val.set_value(true);
         match get_attribute(e, b"val") {
-            Some(v) => {self.val.set_value_string(v);},
-            None => {},
+            Some(v) => {
+                self.val.set_value_string(v);
+            }
+            None => {}
         }
     }
 
