@@ -13,7 +13,7 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct Cell {
     coordinate: Coordinate,
     pub(crate)cell_value: CellValue,
