@@ -1,27 +1,27 @@
-use super::Column;
-use super::Row;
+use super::ColumnReference;
+use super::RowReference;
 use helper::coordinate::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Coordinate {
-    column: Column,
-    row: Row,
+    column: ColumnReference,
+    row: RowReference,
 }
 impl Coordinate {
-    pub fn get_col_num(&self)-> &usize {
+    pub fn get_col_num(&self)-> &u32 {
         &self.column.get_num()
     }
 
-    pub fn set_col_num(&mut self, value:usize)-> &mut Self {
+    pub fn set_col_num(&mut self, value:u32)-> &mut Self {
         self.column.set_num(value);
         self
     }
 
-    pub fn get_row_num(&self) -> &usize {
+    pub fn get_row_num(&self) -> &u32 {
         &self.row.get_num()
     }
 
-    pub fn set_row_num(&mut self, value:usize)-> &mut Self {
+    pub fn set_row_num(&mut self, value:u32)-> &mut Self {
         self.row.set_num(value);
         self
     }
@@ -57,21 +57,21 @@ impl Coordinate {
         coordinate_from_index_with_lock(&self.column.get_num(), &self.row.get_num(), &self.column.get_is_lock(), &self.row.get_is_lock())
     }
 
-    pub(crate) fn is_mine(&self, col_num:&usize, row_num:&usize)->bool {
+    pub(crate) fn is_mine(&self, col_num:&u32, row_num:&u32)->bool {
         self.column.is_mine(col_num) && self.row.is_mine(row_num)
     }
 
-    pub(crate) fn adjustment_insert_coordinate(&mut self, root_col_num:&usize, offset_col_num:&usize, root_row_num:&usize, offset_row_num:&usize) {
+    pub(crate) fn adjustment_insert_coordinate(&mut self, root_col_num:&u32, offset_col_num:&u32, root_row_num:&u32, offset_row_num:&u32) {
         self.column.adjustment_insert_coordinate(root_col_num, offset_col_num);
         self.row.adjustment_insert_coordinate(root_row_num, offset_row_num);
     }
 
-    pub(crate) fn adjustment_remove_coordinate(&mut self, root_col_num:&usize, offset_col_num:&usize, root_row_num:&usize, offset_row_num:&usize) {
+    pub(crate) fn adjustment_remove_coordinate(&mut self, root_col_num:&u32, offset_col_num:&u32, root_row_num:&u32, offset_row_num:&u32) {
         self.column.adjustment_remove_coordinate(root_col_num, offset_col_num);
         self.row.adjustment_remove_coordinate(root_row_num, offset_row_num);
     }
 
-    pub(crate) fn is_remove(&self, root_col_num:&usize, offset_col_num:&usize, root_row_num:&usize, offset_row_num:&usize)->bool {
+    pub(crate) fn is_remove(&self, root_col_num:&u32, offset_col_num:&u32, root_row_num:&u32, offset_row_num:&u32)->bool {
         if self.column.is_remove(root_col_num, offset_col_num) {
             return true;
         }
