@@ -10,7 +10,7 @@ use quick_xml::Writer;
 use quick_xml::Reader;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct BodyProperties {
     vert_overflow: Option<String>,
     horz_overflow: Option<String>,
