@@ -8,7 +8,7 @@ use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct AxisPosition {
     val: EnumValue<AxisPositionValues>,
 }
