@@ -15,7 +15,7 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct ManualLayout {
     height: Option<Height>,
     height_mode: Option<HeightMode>,
