@@ -8,7 +8,7 @@ use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct NumberingFormat {
     format_code: StringValue,
     source_linked: BooleanValue,
