@@ -6,7 +6,7 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct Scaling {
     orientation: Orientation,
 }
@@ -15,11 +15,11 @@ impl Scaling {
         &self.orientation
     }
 
-    pub fn get_orientation_mut(&mut self)-> &Orientation {
+    pub fn get_orientation_mut(&mut self)-> &mut Orientation {
         &mut self.orientation
     }
 
-    pub fn set_orientation(&mut self, value:Orientation)-> &mut Scaling {
+    pub fn set_orientation(&mut self, value:Orientation)-> &mut Self {
         self.orientation = value;
         self
     }
