@@ -16,7 +16,7 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct SeriesAxis {
     axis_id: AxisId,
     scaling: Scaling,
