@@ -13,7 +13,7 @@ use quick_xml::Writer;
 use quick_xml::Reader;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct ShapeProperties {
     pattern_fill: Option<PatternFill>,
     transform2d: Option<Transform2D>,
