@@ -7,7 +7,7 @@ use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct Smooth {
     val: BooleanValue,
 }
@@ -16,7 +16,7 @@ impl Smooth {
         &self.val.get_value()
     }
 
-    pub fn set_val(&mut self, value:bool)-> &mut Smooth {
+    pub fn set_val(&mut self, value:bool)-> &mut Self {
         self.val.set_value(value);
         self
     }
