@@ -8,7 +8,7 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct Title {
     chart_text: Option<ChartText>,
     layout: Option<Layout>,
@@ -82,6 +82,11 @@ impl Title {
                         b"c:overlay" => {
                             &mut self.overlay.set_attributes(reader, e);
                         }
+                        b"c:layout" => {
+                            let mut obj = Layout::default();
+                            obj.set_attributes(reader, e, true);
+                            self.set_layout(obj);
+                        }
                         _ => (),
                     }
                 },
