@@ -18,7 +18,7 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct ValueAxis {
     axis_id: AxisId,
     scaling: Scaling,
@@ -39,11 +39,11 @@ impl ValueAxis {
         &self.axis_id
     }
 
-    pub fn get_axis_id_mut(&mut self)-> &AxisId {
+    pub fn get_axis_id_mut(&mut self)-> &mut AxisId {
         &mut self.axis_id
     }
 
-    pub fn set_axis_id(&mut self, value:AxisId)-> &mut ValueAxis {
+    pub fn set_axis_id(&mut self, value:AxisId)-> &mut Self {
         self.axis_id = value;
         self
     }
@@ -52,11 +52,11 @@ impl ValueAxis {
         &self.scaling
     }
 
-    pub fn get_scaling_mut(&mut self)-> &Scaling {
+    pub fn get_scaling_mut(&mut self)-> &mut Scaling {
         &mut self.scaling
     }
 
-    pub fn set_scaling(&mut self, value:Scaling)-> &mut ValueAxis {
+    pub fn set_scaling(&mut self, value:Scaling)-> &mut Self {
         self.scaling = value;
         self
     }
@@ -65,11 +65,11 @@ impl ValueAxis {
         &self.delete
     }
 
-    pub fn get_delete_mut(&mut self)-> &Delete {
+    pub fn get_delete_mut(&mut self)-> &mut Delete {
         &mut self.delete
     }
 
-    pub fn set_delete(&mut self, value:Delete)-> &mut ValueAxis {
+    pub fn set_delete(&mut self, value:Delete)-> &mut Self {
         self.delete = value;
         self
     }
@@ -78,11 +78,11 @@ impl ValueAxis {
         &self.axis_position
     }
 
-    pub fn get_axis_position_mut(&mut self)-> &AxisPosition {
+    pub fn get_axis_position_mut(&mut self)-> &mut AxisPosition {
         &mut self.axis_position
     }
 
-    pub fn set_axis_position(&mut self, value:AxisPosition)-> &mut ValueAxis {
+    pub fn set_axis_position(&mut self, value:AxisPosition)-> &mut Self {
         self.axis_position = value;
         self
     }
@@ -91,11 +91,11 @@ impl ValueAxis {
         &self.major_gridlines
     }
 
-    pub fn get_major_gridlines_mut(&mut self)-> &Option<MajorGridlines> {
+    pub fn get_major_gridlines_mut(&mut self)-> &mut Option<MajorGridlines> {
         &mut self.major_gridlines
     }
 
-    pub fn set_major_gridlines(&mut self, value:MajorGridlines)-> &mut ValueAxis {
+    pub fn set_major_gridlines(&mut self, value:MajorGridlines)-> &mut Self {
         self.major_gridlines = Some(value);
         self
     }
@@ -104,11 +104,11 @@ impl ValueAxis {
         &self.title
     }
 
-    pub fn get_title_mut(&mut self)-> &Option<Title> {
+    pub fn get_title_mut(&mut self)-> &mut Option<Title> {
         &mut self.title
     }
 
-    pub fn set_title(&mut self, value:Title)-> &mut ValueAxis {
+    pub fn set_title(&mut self, value:Title)-> &mut Self {
         self.title = Some(value);
         self
     }
@@ -117,11 +117,11 @@ impl ValueAxis {
         &self.numbering_format
     }
 
-    pub fn get_numbering_format_mut(&mut self)-> &NumberingFormat {
+    pub fn get_numbering_format_mut(&mut self)-> &mut NumberingFormat {
         &mut self.numbering_format
     }
 
-    pub fn set_numbering_format(&mut self, value:NumberingFormat)-> &mut ValueAxis {
+    pub fn set_numbering_format(&mut self, value:NumberingFormat)-> &mut Self {
         self.numbering_format = value;
         self
     }
@@ -130,11 +130,11 @@ impl ValueAxis {
         &self.major_tick_mark
     }
 
-    pub fn get_major_tick_mark_mut(&mut self)-> &MajorTickMark {
+    pub fn get_major_tick_mark_mut(&mut self)-> &mut MajorTickMark {
         &mut self.major_tick_mark
     }
 
-    pub fn set_major_tick_mark(&mut self, value:MajorTickMark)-> &mut ValueAxis {
+    pub fn set_major_tick_mark(&mut self, value:MajorTickMark)-> &mut Self {
         self.major_tick_mark = value;
         self
     }
@@ -143,11 +143,11 @@ impl ValueAxis {
         &self.minor_tick_mark
     }
 
-    pub fn get_minor_tick_mark_mut(&mut self)-> &MinorTickMark {
+    pub fn get_minor_tick_mark_mut(&mut self)-> &mut MinorTickMark {
         &mut self.minor_tick_mark
     }
 
-    pub fn set_minor_tick_mark(&mut self, value:MinorTickMark)-> &mut ValueAxis {
+    pub fn set_minor_tick_mark(&mut self, value:MinorTickMark)-> &mut Self {
         self.minor_tick_mark = value;
         self
     }
@@ -156,11 +156,11 @@ impl ValueAxis {
         &self.tick_label_position
     }
 
-    pub fn get_tick_label_position_mut(&mut self)-> &TickLabelPosition {
+    pub fn get_tick_label_position_mut(&mut self)-> &mut TickLabelPosition {
         &mut self.tick_label_position
     }
 
-    pub fn set_tick_label_position(&mut self, value:TickLabelPosition)-> &mut ValueAxis {
+    pub fn set_tick_label_position(&mut self, value:TickLabelPosition)-> &mut Self {
         self.tick_label_position = value;
         self
     }
@@ -169,11 +169,11 @@ impl ValueAxis {
         &self.crossing_axis
     }
 
-    pub fn get_tick_crossing_axis_mut(&mut self)-> &CrossingAxis {
+    pub fn get_tick_crossing_axis_mut(&mut self)-> &mut CrossingAxis {
         &mut self.crossing_axis
     }
 
-    pub fn set_tick_crossing_axis(&mut self, value:CrossingAxis)-> &mut ValueAxis {
+    pub fn set_tick_crossing_axis(&mut self, value:CrossingAxis)-> &mut Self {
         self.crossing_axis = value;
         self
     }
@@ -182,11 +182,11 @@ impl ValueAxis {
         &self.crosses
     }
 
-    pub fn get_crosses_mut(&mut self)-> &Crosses {
+    pub fn get_crosses_mut(&mut self)-> &mut Crosses {
         &mut self.crosses
     }
 
-    pub fn set_crosses(&mut self, value:Crosses)-> &mut ValueAxis {
+    pub fn set_crosses(&mut self, value:Crosses)-> &mut Self {
         self.crosses = value;
         self
     }
@@ -195,11 +195,11 @@ impl ValueAxis {
         &self.cross_between
     }
 
-    pub fn get_cross_between_mut(&mut self)-> &CrossBetween {
+    pub fn get_cross_between_mut(&mut self)-> &mut CrossBetween {
         &mut self.cross_between
     }
 
-    pub fn set_cross_between(&mut self, value:CrossBetween)-> &mut ValueAxis {
+    pub fn set_cross_between(&mut self, value:CrossBetween)-> &mut Self {
         self.cross_between = value;
         self
     }
