@@ -8,7 +8,7 @@ use quick_xml::Writer;
 use quick_xml::Reader;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct PresetDash {
     val:EnumValue<PresetLineDashValues>,
 }
