@@ -7,7 +7,7 @@ use quick_xml::Writer;
 use quick_xml::Reader;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct NonVisualGraphicFrameProperties {
     non_visual_drawing_properties: NonVisualDrawingProperties,
     non_visual_graphic_frame_drawing_properties: NonVisualGraphicFrameDrawingProperties,
@@ -50,7 +50,7 @@ impl NonVisualGraphicFrameProperties {
                 Ok(Event::Empty(ref e)) => {
                     match e.name() {
                         b"xdr:cNvPr" => {
-                            &mut self.non_visual_drawing_properties.set_attributes(reader, e);
+                            &mut self.non_visual_drawing_properties.set_attributes(reader, e, true);
                         },
                         b"xdr:cNvGraphicFramePr" => {
                             &mut self.non_visual_graphic_frame_drawing_properties.set_attributes(reader, e);
@@ -77,7 +77,7 @@ impl NonVisualGraphicFrameProperties {
         write_start_tag(writer, "xdr:nvGraphicFramePr", vec![], false);
 
         // xdr:cNvPr
-        &self.non_visual_drawing_properties.write_to(writer);
+        &self.non_visual_drawing_properties.write_to(writer, &0);
         
         // xdr:cNvGraphicFramePr
         &self.non_visual_graphic_frame_drawing_properties.write_to(writer);
