@@ -6,7 +6,7 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct ShapeStyle {
     line_reference: Option<StyleMatrixReferenceType>,
     fill_reference: Option<StyleMatrixReferenceType>,
