@@ -7,7 +7,7 @@ use quick_xml::Writer;
 use quick_xml::Reader;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct StartConnection {
     id: UInt32Value,
     index: UInt32Value,
