@@ -10,7 +10,7 @@ use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct Pane {
     horizontal_split: DoubleValue,
     vertical_split: DoubleValue,
