@@ -9,9 +9,9 @@ pub(crate) struct PhoneticRun {
 
 }
 impl PhoneticRun {
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         _e:&BytesStart
     ) {
         let mut buf = Vec::new();
@@ -31,7 +31,7 @@ impl PhoneticRun {
         }
     }
 
-    pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
+    pub(crate) fn write_to(&self, _writer: &mut Writer<Cursor<Vec<u8>>>) {
 
     }
 }
