@@ -10,7 +10,7 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
 
-#[derive(Default, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct SheetView {
     tab_selected: BooleanValue,
     workbook_view_id: UInt32Value,
