@@ -27,6 +27,7 @@ mod comment;
 mod vml_drawing;
 mod media;
 mod embeddings;
+mod vml_drawing_rels;
 
 #[derive(Debug)]
 pub enum XlsxError {
@@ -94,20 +95,24 @@ pub fn write_writer<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, writer:
     // Add worksheets and relationships (drawings, ...)
     let mut chart_id = 1;
     let mut drawing_id = 1;
+    let mut vml_drawing_id = 1;
     let mut comment_id = 1;
+    let mut ole_bin_id = 1;
+    let mut ole_excel_id = 1;
     let mut shared_string_table = SharedStringTable::default();
     shared_string_table.init_setup();
     let mut stylesheet = Stylesheet::default();
     stylesheet.init_setup();
     for i in 0..spreadsheet.get_sheet_count() {
         let p_worksheet_id:&str = &(i+1).to_string();
-        let _ = worksheet::write(&spreadsheet, &i, &mut shared_string_table, &mut stylesheet, &mut arv);
+        let _ = worksheet::write(&spreadsheet, &i, &mut shared_string_table, &mut stylesheet, &drawing_id, &mut arv);
         let worksheet = &spreadsheet.get_sheet_collection()[i];
-        let _ = worksheet_rels::write(worksheet, p_worksheet_id, &drawing_id, &comment_id,  &mut arv);
+        let _ = worksheet_rels::write(worksheet, p_worksheet_id, &drawing_id, &vml_drawing_id, &comment_id,  &mut arv, &ole_bin_id, &ole_excel_id);
         let _ = drawing::write(worksheet, &drawing_id, &mut arv);
         let _ = drawing_rels::write(worksheet, &drawing_id, &chart_id, &mut arv);
         let _ = comment::write(worksheet, &comment_id,  &mut arv);
-        let _ = vml_drawing::write(worksheet, &comment_id,  &mut arv);
+        let _ = vml_drawing::write(worksheet, &drawing_id, &vml_drawing_id,  &mut arv);
+        let _ = vml_drawing_rels::write(worksheet, &vml_drawing_id,  &mut arv);
 
         if worksheet.has_drawing_object() {
             drawing_id += 1;
@@ -117,16 +122,23 @@ pub fn write_writer<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, writer:
             comment_id += 1;
         }
 
-        for graphic_frame in worksheet.get_worksheet_drawing().get_graphic_frame_collection(){
-            let chart_space = graphic_frame.get_graphic().get_graphic_data().get_chart_space();
-            let _ = chart::write(chart_space, &chart_id, &mut arv);
+        if worksheet.has_legacy_drawing() {
+            vml_drawing_id += 1;
+        }
+
+        for chart in worksheet.get_worksheet_drawing().get_chart_collection(){
+            let chart_space = chart.get_chart_space();
+            let _ = chart::write(chart_space, &chart_id, &mut arv, spreadsheet);
             chart_id += 1;
         }
 
-        let _ = media::write(worksheet, &mut arv, "xl/media");
-        let _ = embeddings::write(worksheet, &mut arv, "xl/embeddings");
+        let _ = embeddings::write(worksheet, &mut arv, "xl/embeddings", &mut ole_bin_id, &mut ole_excel_id);
     }
 
+    // Add Media
+    let images = spreadsheet.get_image_collection();
+    let _ = media::write(images, &mut arv, "xl/media");
+
     // Add SharedStrings
     let _ = shared_strings::write(&shared_string_table, &mut arv).unwrap();
 
